aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2018-08-31 16:24:27 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2018-08-31 16:24:27 +0200
commit12a1044b81e39b8ca03faca641dacf76dda6c506 (patch)
treed2236128319b441259717b89cdeaa10ada9d6690
parentc76736eb1dde2fe5a8ae344dca2b018c79bdc218 (diff)
Adjust terminology in diagnostic and comments
-rw-r--r--build2/parser.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/build2/parser.cxx b/build2/parser.cxx
index 1dd49b6..4f532fc 100644
--- a/build2/parser.cxx
+++ b/build2/parser.cxx
@@ -470,7 +470,7 @@ namespace build2
if (tt == type::newline)
{
// See if this is a target scope.
//
if (peek () == type::lcbrace)
{
@@ -482,13 +482,13 @@ namespace build2
fail (t) << "expected newline after {";
if (at.first)
- fail (at.second) << "attributes before target scope";
+ fail (at.second) << "attributes before target block";
else
attributes_pop ();
// @@ TODO: target scope (also prerequisite scope below).
//
- fail (nloc) << "target scopes are not yet supported" <<
+ fail (nloc) << "target blocks are not yet supported" <<
info << "if migrating, remove ':'";
if (tt != type::rcbrace)
@@ -789,7 +789,7 @@ namespace build2
// Set the variable in the last pns.size() prerequisites of each
// target. This code is similar to target-specific case above.
//
// @@ TODO prerequisite scope (also target scope above).
//
next (t, tt);
attributes_push (t, tt);
@@ -470,7 +470,7 @@ namespace build2
if (tt == type::newline)
{
- // See if this is a target scope.
+ // See if this is a target block.
//
if (peek () == type::lcbrace)
@@ -482,13 +482,13 @@ namespace build2
else
attributes_pop ();
- // @@ TODO: target scope (also prerequisite scope below).
+ // @@ TODO: target block (also prerequisite block below).
//
@@ -789,7 +789,7 @@ namespace build2
// target. This code is similar to target-specific case above.
//
- // @@ TODO prerequisite scope (also target scope above).
+ // @@ TODO prerequisite block (also target block above).
//
next (t, tt);